IterableByOverlaps

Trait IterableByOverlaps 

pub trait IterableByOverlaps<'a, R, I>
where R: Region, I: Iterator<Item = R>,
{ // Required method fn overlaps( self, memory: &'a [u8], base_address: u32, ) -> OverlapIterator<'_, R, I> ; }
Trait allowing us to automatically add an overlaps function to all iterators over Region

Required Methods

fn overlaps( self, memory: &'a [u8], base_address: u32, ) -> OverlapIterator<'_, R, I>

Obtain an OverlapIterator over a subslice of memory that overlaps with the region in self

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<'a, R, I> IterableByOverlaps<'a, R, I> for I
where R: Region, I: Iterator<Item = R>,

Blanket implementation for all types implementing Iterator over [Regions]