Trait embedded_storage::iter::IterableByOverlaps
source · [−]pub trait IterableByOverlaps<'a, R, I> where
R: Region,
I: Iterator<Item = R>, {
fn overlaps(
self,
memory: &'a [u8],
base_address: u32
) -> OverlapIterator<'_, R, I>ⓘNotable traits for OverlapIterator<'a, R, I>impl<'a, R, I> Iterator for OverlapIterator<'a, R, I> where
R: Region,
I: Iterator<Item = R>, type Item = (&'a [u8], R, u32);;
}Expand description
Trait allowing us to automatically add an overlaps function to all iterators over Region
Required methods
Obtain an OverlapIterator over a subslice of memory that overlaps with the region in self
Implementors
impl<'a, R, I> IterableByOverlaps<'a, R, I> for I where
R: Region,
I: Iterator<Item = R>,
Blanket implementation for all types implementing Iterator over [Regions]