Technology specific traits for NOR Flashes
Structs
- RmwMultiwrite
NorFlash Storage - Read-Modify-Write (RMW) Multi-Write Nor Flash storage structure.
- RmwNor
Flash Storage - Read-Modify-Write (RMW) Nor Flash storage structure.
Enums
- NorFlash
Error Kind - NOR flash error kinds.
Traits
- Error
Type - A trait that NorFlash implementations can use to share an error type.
- Multiwrite
NorFlash - Marker trait for NorFlash relaxing the restrictions on
write. - NorFlash
- NOR flash trait.
- NorFlash
Error - NOR flash errors.
- Read
NorFlash - Read only NOR flash trait.
Functions
- check_
erase - Return whether an erase operation is aligned and within bounds.
- check_
read - Return whether a read operation is within bounds.
- check_
write - Return whether a write operation is aligned and within bounds.