Technology specific traits for NOR Flashes

Structs

Enums

NOR flash error kinds.

Traits

A trait that NorFlash implementations can use to share an error type.

Marker trait for NorFlash relaxing the restrictions on write.

NOR flash trait.

NOR flash errors.

Read only NOR flash trait.

Functions

Return whether an erase operation is aligned and within bounds.

Return whether a read operation is within bounds.

Return whether a write operation is aligned and within bounds.