NorFlashError

Trait NorFlashError 

pub trait NorFlashError: Debug {
    // Required method
    fn kind(&self) -> NorFlashErrorKind;
}
NOR flash errors.

NOR flash implementations must use an error type implementing this trait. This permits generic code to extract a generic error kind.

Required Methods

fn kind(&self) -> NorFlashErrorKind

Convert a specific NOR flash error into a generic error kind.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl NorFlashError for Infallible

Implementors