pub trait NorFlashError: Debug {
// Required method
fn kind(&self) -> NorFlashErrorKind;
}Expand description
NOR flash errors.
NOR flash implementations must use an error type implementing this trait. This permits generic code to extract a generic error kind.
Required Methods
Sourcefn kind(&self) -> NorFlashErrorKind
fn kind(&self) -> NorFlashErrorKind
Convert a specific NOR flash error into a generic error kind.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".