pub trait NorFlashError: Debug {
    fn kind(&self) -> NorFlashErrorKind;
}
NOR flash errors.

NOR flash implementations must use an error type implementing this trait. This permits generic code to extract a generic error kind.

Required methods

Convert a specific NOR flash error into a generic error kind.

Implementations on Foreign Types

Implementors