Trait embedded_storage::nor_flash::NorFlashError
source · [−]pub trait NorFlashError: Debug {
fn kind(&self) -> NorFlashErrorKind;
}Expand description
NOR flash errors.
NOR flash implementations must use an error type implementing this trait. This permits generic code to extract a generic error kind.
Required methods
fn kind(&self) -> NorFlashErrorKind
fn kind(&self) -> NorFlashErrorKind
Convert a specific NOR flash error into a generic error kind.