pub trait ReadNorFlash: ErrorType {
    const READ_SIZE: usize;

    fn read(&mut self, offset: u32, bytes: &mut [u8]) -> Result<(), Self::Error>;
fn capacity(&self) -> usize; }
Read only NOR flash trait.

Associated Constants

The minumum number of bytes the storage peripheral can read

Required methods

Read a slice of data from the storage peripheral, starting the read operation at the given address offset, and reading bytes.len() bytes.

Errors

Returns an error if the arguments are not aligned or out of bounds. The implementation can use the check_read helper function.

The capacity of the peripheral in bytes.

Implementors