Trait embedded_storage::nor_flash::ReadNorFlash
source · [−]pub trait ReadNorFlash: ErrorType {
const READ_SIZE: usize;
fn read(&mut self, offset: u32, bytes: &mut [u8]) -> Result<(), Self::Error>;
fn capacity(&self) -> usize;
}Expand description
Read only NOR flash trait.
Associated Constants
Required methods
Read a slice of data from the storage peripheral, starting the read
operation at the given address offset, and reading bytes.len() bytes.
Errors
Returns an error if the arguments are not aligned or out of bounds. The implementation
can use the check_read helper function.