Trait embedded_storage::Region [−][src]
pub trait Region {
fn contains(&self, address: u32) -> bool;
}Expand description
A region denotes a contiguous piece of memory between two addresses.
Required methods
fn contains(&self, address: u32) -> bool[src]
Check if address is contained in the region of Self